<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="lt">
<context>
    <name>BookmarksWidget</name>
    <message>
        <location filename="../forms/bookmarkswidget.ui" line="32"/>
        <source>Filter:</source>
        <translation>Filtras:</translation>
    </message>
</context>
<context>
    <name>FontDialog</name>
    <message>
        <location filename="../forms/fontdialog.ui" line="14"/>
        <location filename="../forms/fontdialog.ui" line="73"/>
        <source>Select Terminal Font</source>
        <translation>Pasirinkti terminalo šriftą</translation>
    </message>
    <message>
        <location filename="../forms/fontdialog.ui" line="32"/>
        <source>Font:</source>
        <translation>Šriftas:</translation>
    </message>
    <message>
        <location filename="../forms/fontdialog.ui" line="42"/>
        <source>Size:</source>
        <translation>Dydis:</translation>
    </message>
    <message>
        <location filename="../forms/fontdialog.ui" line="59"/>
        <source>Preview</source>
        <translation>Peržiūra</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../mainwindow.cpp" line="92"/>
        <source>Bookmarks</source>
        <translation>Žymelės</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="192"/>
        <source>Press &quot;%1&quot; to see the terminal.</source>
        <translation>Paspauskite &quot;%1&quot;, kad pamatytumėte terminalą.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="241"/>
        <source>&amp;Next Tab</source>
        <translation>&amp;Kita kortelė</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="244"/>
        <source>&amp;Previous Tab</source>
        <translation>&amp;Ankstesnė kortelė</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="253"/>
        <source>Move Tab &amp;Left</source>
        <translation>Perkelti kortelę &amp;kairėn</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="256"/>
        <source>Move Tab &amp;Right</source>
        <translation>Perkelti kortelę &amp;dešinėn</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="275"/>
        <source>Split Terminal &amp;Horizontally</source>
        <translation>Suskaidyti terminalą &amp;horizontaliai</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="278"/>
        <source>Split Terminal &amp;Vertically</source>
        <translation>Suskaidyti terminalą &amp;vertikaliai</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="283"/>
        <source>&amp;Collapse Subterminal</source>
        <translation>&amp;Suskleisti subterminalą</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="234"/>
        <source>&amp;Clear Active Terminal</source>
        <translation>&amp;Išvalyti aktyvų terminalą</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="247"/>
        <source>&amp;Previous Tab in History</source>
        <translation>&amp;Ankstesnė kortelė istorijoje</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="250"/>
        <source>&amp;Next Tab in History</source>
        <translation>&amp;Kita kortelė istorijoje</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="261"/>
        <source>Tab</source>
        <translation>Kortelė</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="262"/>
        <source>Go to</source>
        <translation>Pereiti į</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="286"/>
        <source>&amp;Top Subterminal</source>
        <translation>&amp;Viršutinis subterminalas</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="289"/>
        <source>&amp;Bottom Subterminal</source>
        <translation>&amp;Apatinis subterminalas</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="292"/>
        <source>L&amp;eft Subterminal</source>
        <translation>&amp;Kairysis subterminalas</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="295"/>
        <source>R&amp;ight Subterminal</source>
        <translation>&amp;Dešinysis subterminalas</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="302"/>
        <source>Copy &amp;Selection</source>
        <translation>Kopijuoti &amp;žymėjimą</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="305"/>
        <source>Paste Clip&amp;board</source>
        <translation>Įdėti iš iškar&amp;pinės</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="308"/>
        <source>Paste S&amp;election</source>
        <translation>Įdėti ž&amp;ymėjimą</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="311"/>
        <source>Zoom &amp;in</source>
        <translation>&amp;Didinti</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="314"/>
        <source>Zoom &amp;out</source>
        <translation>&amp;Mažinti</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="317"/>
        <source>Zoom rese&amp;t</source>
        <translation>A&amp;tstatyti mastelį</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="322"/>
        <source>&amp;Find...</source>
        <translation>&amp;Rasti...</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="325"/>
        <source>Handle history...</source>
        <translation>Apdoroti istoriją...</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="333"/>
        <source>&amp;Save Session</source>
        <translation>Į&amp;rašyti seansą</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="339"/>
        <source>&amp;Load Session</source>
        <translation>Į&amp;kelti seansą</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="346"/>
        <source>&amp;Toggle Menu</source>
        <translation>&amp;Perjungti meniu</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="351"/>
        <source>Rename session</source>
        <translation>Pervadinti seansą</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="360"/>
        <source>&amp;New Tab</source>
        <translation>&amp;Nauja kortelė</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="364"/>
        <source>New Tab From &amp;Preset</source>
        <translation>Nauja kortelė iš išankstinių pari&amp;nkčių</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="365"/>
        <source>1 &amp;Terminal</source>
        <translation>1 &amp;terminalas</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="367"/>
        <source>2 &amp;Horizontal Terminals</source>
        <translation>2 &amp;horizontalūs terminalai</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="369"/>
        <source>2 &amp;Vertical Terminals</source>
        <translation>2 &amp;vertikalūs terminalai</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="371"/>
        <source>4 Terminal&amp;s</source>
        <translation>4 termin&amp;аlai</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="377"/>
        <source>&amp;Close Tab</source>
        <translation>&amp;Užverti kortelę</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="380"/>
        <source>&amp;New Window</source>
        <translation>&amp;Naujas langas</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="385"/>
        <source>&amp;Preferences...</source>
        <translation>&amp;Nuostatos...</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="389"/>
        <source>&amp;Quit</source>
        <translation>&amp;Išeiti</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="395"/>
        <source>&amp;Hide Window Borders</source>
        <translation>&amp;Slėpti lango rėmelį</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="413"/>
        <source>&amp;Show Tab Bar</source>
        <translation>&amp;Rodyti kortelių juostą</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="421"/>
        <source>Fullscreen</source>
        <translation>Visas ekranas</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="427"/>
        <source>Toggle Bookmarks</source>
        <translation>Perjungti žymeles</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="435"/>
        <source>&amp;Bottom</source>
        <translation>&amp;Apačioje</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="436"/>
        <source>&amp;Top</source>
        <translation>&amp;Viršuje</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="437"/>
        <location filename="../mainwindow.cpp" line="473"/>
        <source>&amp;Right</source>
        <translation>&amp;Dešinėje</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="438"/>
        <location filename="../mainwindow.cpp" line="474"/>
        <source>&amp;Left</source>
        <translation>&amp;Kairėje</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="456"/>
        <source>&amp;Tabs Layout</source>
        <translation>Kortelių &amp;išdėstymas</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="472"/>
        <source>&amp;None</source>
        <translation>&amp;Nėra</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="490"/>
        <source>S&amp;crollbar Layout</source>
        <translation>S&amp;lankjuostės išdėstymas</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="503"/>
        <source>&amp;BlockCursor</source>
        <translation>&amp;Blokas</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="504"/>
        <source>&amp;UnderlineCursor</source>
        <translation>Pabra&amp;ukimas</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="505"/>
        <source>&amp;IBeamCursor</source>
        <translation>&amp;Dvitėjinė sija</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="522"/>
        <source>&amp;Keyboard Cursor Shape</source>
        <translation>&amp;Klaviatūros žymeklio forma</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="622"/>
        <source>Exit QTerminal</source>
        <translation>Išeiti iš QTerminal</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="624"/>
        <source>Do not ask again</source>
        <translation>Daugiau nebeklausti</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="632"/>
        <source>Are you sure you want to exit?</source>
        <translation>Ar tikrai norite išeiti?</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="663"/>
        <source>A lightweight multiplatform terminal emulator</source>
        <translation>Supaprastintas daugiaplatformis terminalo emuliatorius</translation>
    </message>
</context>
<context>
    <name>PropertiesDialog</name>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="14"/>
        <source>Terminal settings</source>
        <translation>Terminalo nustatymai</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="31"/>
        <source>Appearance</source>
        <translation>Išvaizda</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="39"/>
        <location filename="../forms/propertiesdialog.ui" line="611"/>
        <source>Behavior</source>
        <translation>Elgsena</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="47"/>
        <source>Shortcuts</source>
        <translation>Spartieji klavišai</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="55"/>
        <source>Dropdown</source>
        <translation>Išskleidžiamasis terminalas</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="63"/>
        <source>Bookmarks</source>
        <translation>Žymelės</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="258"/>
        <source>Hide tab bar with only one tab</source>
        <translation>Slėpti kortelių juostą, esant tik vienai kortelei</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="275"/>
        <source>Color scheme</source>
        <translation>Spalvų rinkinys</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="371"/>
        <source>Scrollbar position</source>
        <translation>Slankjuostės vieta</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="204"/>
        <source>Start with preset:</source>
        <translation>Paleisti su išankstine parinktimi:</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="404"/>
        <source>Show a border around the current terminal</source>
        <translation>Rodyti rėmelį aplink esamą terminalą</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="381"/>
        <source>Terminal transparency</source>
        <translation>Terminalo permatomumas</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="394"/>
        <source>Application transparency</source>
        <translation>Programos permatomumas</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="215"/>
        <source>None (single terminal)</source>
        <translation>Nėra (vienas terminalas)</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="220"/>
        <source>2 terminals horizontally</source>
        <translation>2 horizontalūs terminalai</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="225"/>
        <source>2 terminals vertically</source>
        <translation>2 vertikalūs terminalai</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="230"/>
        <source>4 terminals</source>
        <translation>4 terminalai</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="117"/>
        <location filename="../forms/propertiesdialog.ui" line="425"/>
        <source> %</source>
        <translation> %</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="148"/>
        <source>Font</source>
        <translation>Šriftas</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="184"/>
        <source>&amp;Change...</source>
        <translation>&amp;Keisti...</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="454"/>
        <source>Tabs position</source>
        <translation>Kortelių vieta</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="238"/>
        <source>Widget style</source>
        <translation>Valdiklių stilius</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="194"/>
        <source>Show the menu bar</source>
        <translation>Rodyti meniu juostą</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="335"/>
        <source>Cursor shape</source>
        <translation>Žymeklio forma</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="464"/>
        <source>Change window title based on current terminal</source>
        <translation>Keisti lango pavadinimą pagal esamą terminalą</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="481"/>
        <source>Change window icon based on current terminal</source>
        <translation>Keisti lango piktogramą pagal esamą terminalą</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="418"/>
        <source>Enable bi-directional text support</source>
        <translation>Įjungti dvikrypčio teksto palaikymą</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="265"/>
        <source>Background image:</source>
        <translation>Fono paveikslas:</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="290"/>
        <source>Select</source>
        <translation>Pasirinkti</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="488"/>
        <source>Show terminal size on resize</source>
        <translation>Keičiant dydį, rodyti terminalo dydį</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="471"/>
        <source>Fixed tab width:</source>
        <translation>Fiksuotas kortelės plotis:</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="411"/>
        <location filename="../forms/propertiesdialog.ui" line="444"/>
        <source>px</source>
        <translation>pikselių</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="361"/>
        <source>Show close button on each tab</source>
        <translation>Rodyti ant kiekvienos kortelės užvėrimo mygtuką</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="248"/>
        <source>Terminal margin</source>
        <translation>Terminalo paraštė</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="498"/>
        <source>Use box drawing characters contained in the font</source>
        <translation>Naudoti šrifte esančius langelio piešimo simbolius</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="505"/>
        <source>Accelerators are activated by Alt and can interfere with the terminal.</source>
        <translation>Prieigos klavišai yra aktyvuojami Alt klavišu ir gali trukdyti terminalui.</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="508"/>
        <source>No menu bar accelerator</source>
        <translation>Jokių meniu juostos prieigos klavišų</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="586"/>
        <source>Emulation</source>
        <translation>Emuliacija</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="711"/>
        <source>Action after paste</source>
        <translation>Veiksmas po įdėjimo</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="748"/>
        <source>Confirm multiline paste</source>
        <translation>Patvirtinti kelių eilučių įdėjimą</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="789"/>
        <source>Trim trailing newlines in pasted text</source>
        <translation>Apkirpti įdėtame tekste naujas eilutes</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="724"/>
        <source>Open new terminals in current working directory</source>
        <translation>Atverti naujus terminalus esamame darbiniame kataloge</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="755"/>
        <source>Save Size when closing</source>
        <translation>Užveriant, įsiminti dydį</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="796"/>
        <source>Save Position when closing</source>
        <translation>Užveriant, įsiminti poziciją</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="772"/>
        <source>Ask for confirmation when closing</source>
        <translation>Užveriant, klausti patvirtinimo</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="816"/>
        <source>Unlimited history</source>
        <translation>Neribota istorija</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="782"/>
        <source>History size (in lines)</source>
        <translation>Istorijos dydis (eilutėmis)</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="741"/>
        <source>Default $TERM</source>
        <translation>Numatytasis $TERM</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="632"/>
        <source>Start with this size:</source>
        <translation>Paleisti šio dydžio:</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="299"/>
        <source>Background mode:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="307"/>
        <source>None</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="312"/>
        <source>Stretch</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="317"/>
        <source>Zoom</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="322"/>
        <source>Fit</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="327"/>
        <source>Center</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="495"/>
        <source>Specify whether box drawing characters should be drawn by QTerminal internally or left to underlying font rendering libraries.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="515"/>
        <source>Toggles usage of bold font face for rendering intense colors</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="518"/>
        <source>Use bold font face for intense colors</source>
        <translation>Ryškioms spalvoms naudoti pusjuodį šriftą</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="525"/>
        <source>&amp;Hide Window Borders</source>
        <translation>&amp;Slėpti lango rėmelį</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="595"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Which behavior to emulate. Note that this does not have to match your operating system.&lt;/p&gt;&lt;p&gt;If you are not sure, use the &lt;span style=&quot; font-weight:600;&quot;&gt;default&lt;/span&gt; emulation.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Kurią veikseną emuliuoti. Turėkite omenyje, kad tai neturi atitikti jūsų operacinę sistemą.&lt;/p&gt;&lt;p&gt;Jei nesate tikri, naudokite &lt;span style=&quot; font-weight:600;&quot;&gt;numatytąją&lt;/span&gt; emulation.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="617"/>
        <source>This command will be run with an argument containing the file name of a tempfile containing the scrollback history</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="620"/>
        <source>Handle history command</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="639"/>
        <location filename="../forms/propertiesdialog.ui" line="653"/>
        <source> px</source>
        <translation> piks.</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="660"/>
        <source>Get current size</source>
        <translation>Gauti dabartinį dydį</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="731"/>
        <source>Open new tab to the right of the active tab</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="734"/>
        <source>If unchecked the new tab will be opened as the rightmost tab</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="762"/>
        <source>Close tab on middle-click</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="823"/>
        <source>Forcefully disable bracketed paste mode</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="826"/>
        <source>Bracketed paste mode is useful for pasting multiline strings.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="844"/>
        <source>To edit a Shortcut:
1. Double-click its Key
2. Press the desired combination and release it
3. Click on a Shortcut or press Enter

To remove/disable a Shortcut, at point 2 press only a modifier (like Shift)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="874"/>
        <source>Shortcut</source>
        <translation>Spartusis klavišas</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="879"/>
        <source>Key</source>
        <translation>Klavišai</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="891"/>
        <source>Show on start</source>
        <translation>Rodyti paleisties metu</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="898"/>
        <source>Size</source>
        <translation>Dydis</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="909"/>
        <source>Height</source>
        <translation>Aukštis</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="919"/>
        <location filename="../forms/propertiesdialog.ui" line="936"/>
        <source>%</source>
        <translation>%</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="926"/>
        <source>Width</source>
        <translation>Plotis</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="950"/>
        <source>Shortcut:</source>
        <translation>Spartusis klavišas:</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="982"/>
        <source>Edit bookmark file contents</source>
        <translation>Redaguoti žymelių failo turinį</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="1004"/>
        <source>Enable bookmarks</source>
        <translation>Įjungti žymeles</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="1013"/>
        <source>Bookmark file</source>
        <translation>Žymelių failas</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="1026"/>
        <source>Find...</source>
        <translation>Rasti...</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="1035"/>
        <source>You can specify your own bookmarks file location. It allows easy bookmark sharing with tools like OwnCloud or Dropbox.</source>
        <translation>Jūs galite nurodyti savo asmeninę žymelių failo vietą. Tai leidžia lengvai bendrinti žymeles su tokiais įrankiais kaip OwnCloud ar Dropbox.</translation>
    </message>
    <message>
        <location filename="../propertiesdialog.cpp" line="155"/>
        <source>No scrollbar</source>
        <translation>Be slankjuostės</translation>
    </message>
    <message>
        <location filename="../propertiesdialog.cpp" line="155"/>
        <location filename="../propertiesdialog.cpp" line="161"/>
        <source>Left</source>
        <translation>Kairėje</translation>
    </message>
    <message>
        <location filename="../propertiesdialog.cpp" line="155"/>
        <location filename="../propertiesdialog.cpp" line="161"/>
        <source>Right</source>
        <translation>Dešinėje</translation>
    </message>
    <message>
        <location filename="../propertiesdialog.cpp" line="161"/>
        <source>Top</source>
        <translation>Viršuje</translation>
    </message>
    <message>
        <location filename="../propertiesdialog.cpp" line="161"/>
        <source>Bottom</source>
        <translation>Apačioje</translation>
    </message>
    <message>
        <location filename="../propertiesdialog.cpp" line="174"/>
        <source>BlockCursor</source>
        <translation>Blokas</translation>
    </message>
    <message>
        <location filename="../propertiesdialog.cpp" line="174"/>
        <source>UnderlineCursor</source>
        <translation>Pabraukimas</translation>
    </message>
    <message>
        <location filename="../propertiesdialog.cpp" line="174"/>
        <source>IBeamCursor</source>
        <translation>Dvitėjinė sija</translation>
    </message>
    <message>
        <location filename="../propertiesdialog.cpp" line="192"/>
        <source>No move</source>
        <translation>Nejudėti</translation>
    </message>
    <message>
        <location filename="../propertiesdialog.cpp" line="192"/>
        <source>Scrolling to top</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../propertiesdialog.cpp" line="192"/>
        <source>Scrolling to bottom</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../propertiesdialog.cpp" line="390"/>
        <source>Images (*.bmp *.jpg *.png *.svg *.xpm)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../propertiesdialog.cpp" line="199"/>
        <location filename="../propertiesdialog.cpp" line="294"/>
        <source>System Default</source>
        <translation>Sistemos numatytasis</translation>
    </message>
    <message>
        <location filename="../propertiesdialog.cpp" line="389"/>
        <source>Choose a background image</source>
        <translation>Pasirinkti fono paveikslą</translation>
    </message>
    <message>
        <location filename="../propertiesdialog.cpp" line="466"/>
        <source>Open or create bookmarks file</source>
        <translation>Atverti ar sukurti žymelių failą</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../bookmarkswidget.cpp" line="108"/>
        <source>Local Bookmarks</source>
        <translation>Vietinės žymelės</translation>
    </message>
    <message>
        <location filename="../bookmarkswidget.cpp" line="166"/>
        <source>Synchronized Bookmarks</source>
        <translation>Sinchronizuotos žymelės</translation>
    </message>
</context>
<context>
    <name>TabWidget</name>
    <message>
        <location filename="../tabwidget.cpp" line="78"/>
        <location filename="../tabwidget.cpp" line="232"/>
        <source>Shell No. %1</source>
        <translation>Apvalkalas nr. %1</translation>
    </message>
    <message>
        <location filename="../tabwidget.cpp" line="200"/>
        <source>Tab name</source>
        <translation>Kortelės pavadinimas</translation>
    </message>
    <message>
        <location filename="../tabwidget.cpp" line="201"/>
        <source>New tab name:</source>
        <translation>Naujas kortelės pavadinimas:</translation>
    </message>
    <message>
        <location filename="../tabwidget.cpp" line="221"/>
        <source>Select new tab title color</source>
        <translation>Pasirinkite naują kortelės pavadinimo spalvą</translation>
    </message>
    <message>
        <location filename="../tabwidget.cpp" line="242"/>
        <source>Close session</source>
        <translation>Užverti seansą</translation>
    </message>
    <message>
        <location filename="../tabwidget.cpp" line="244"/>
        <source>Change title color</source>
        <translation>Keisti pavadinimo spalvą</translation>
    </message>
</context>
<context>
    <name>TermWidgetHolder</name>
    <message>
        <location filename="../termwidgetholder.cpp" line="79"/>
        <source>Load Session</source>
        <translation>Įkelti seansą</translation>
    </message>
    <message>
        <location filename="../termwidgetholder.cpp" line="80"/>
        <source>List of saved sessions:</source>
        <translation>Įrašytų seansų sąrašas:</translation>
    </message>
</context>
<context>
    <name>mainWindow</name>
    <message>
        <location filename="../forms/qterminal.ui" line="14"/>
        <source>MainWindow</source>
        <translation>Pagrindinis langas</translation>
    </message>
    <message>
        <location filename="../forms/qterminal.ui" line="59"/>
        <source>&amp;File</source>
        <translation>&amp;Failas</translation>
    </message>
    <message>
        <location filename="../forms/qterminal.ui" line="67"/>
        <source>&amp;Actions</source>
        <translation>&amp;Veiksmai</translation>
    </message>
    <message>
        <location filename="../forms/qterminal.ui" line="72"/>
        <source>&amp;Help</source>
        <translation>Ž&amp;inynas</translation>
    </message>
    <message>
        <location filename="../forms/qterminal.ui" line="79"/>
        <source>&amp;View</source>
        <translation>&amp;Rodinys</translation>
    </message>
    <message>
        <location filename="../forms/qterminal.ui" line="84"/>
        <source>&amp;Edit</source>
        <translation>&amp;Taisa</translation>
    </message>
    <message>
        <location filename="../forms/qterminal.ui" line="100"/>
        <source>&amp;About...</source>
        <translation>&amp;Apie...</translation>
    </message>
    <message>
        <location filename="../forms/qterminal.ui" line="105"/>
        <source>About &amp;Qt...</source>
        <translation>Apie &amp;Qt...</translation>
    </message>
</context>
</TS>
